==> jc-1.4.0.tar.gz: javax/swing/plaf/ActionMapUIResource.h <==
// public class javax.swing.plaf.ActionMapUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 93c843e5a4c9d4b3 javax_swing_ActionMap
// @dep_class 30ae1dc005c7b7e1 javax_swing_plaf_ActionMapUIResource

// header file dependencies
// @dep_header javax_swing_ActionMap

#include "javax/swing/ActionMap.h"

#ifndef _JC_javax_swing_plaf_ActionMapUIResource_H_
#define _JC_javax_swing_plaf_ActionMapUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$sub_refs	_jc_javax_swing_plaf_ActionMapUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs	_jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$refs	_jc_javax_swing_plaf_ActionMapUIResource$refs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$nonrefs	_jc_javax_swing_plaf_ActionMapUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$object	_jc_javax_swing_plaf_ActionMapUIResource$object;

typedef const struct _jc_javax_swing_plaf_ActionMapUIResource$vmethods	_jc_javax_swing_plaf_ActionMapUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_ActionMapUIResource$vtable	_jc_javax_swing_plaf_ActionMapUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_ActionMapUIResource$vtype	_jc_javax_swing_plaf_ActionMapUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ActionMapUIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ActionMapUIResource$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_ActionMapUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ActionMapUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ActionMap$vmethods	javax_swing_ActionMap;
	_jc_javax_swing_plaf_ActionMapUIResource$vmethods	javax_swing_plaf_ActionMapUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_ActionMapUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ActionMapUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ActionMapUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ActionMapUIResource$refs {
    _jc_javax_swing_plaf_ActionMapUIResource$sub_refs	javax_swing_plaf_ActionMapUIResource;
    _jc_javax_swing_ActionMap$sub_refs	javax_swing_ActionMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ActionMapUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ActionMap$sub_nonrefs	javax_swing_ActionMap;
    _jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs	javax_swing_plaf_ActionMapUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_ActionMapUIResource$object {
	_jc_javax_swing_plaf_ActionMapUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ActionMapUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_ActionMapUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ActionMapUIResource$vtype _jc_javax_swing_plaf_ActionMapUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ActionMapUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ActionMapUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_ActionMapUIResource_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/ActionMapUIResource.h <==
// public class javax.swing.plaf.ActionMapUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 93c843e5a4c9d4b3 javax_swing_ActionMap
// @dep_class 30ae1dc005c7b7e1 javax_swing_plaf_ActionMapUIResource

// header file dependencies
// @dep_header javax_swing_ActionMap

#include "javax/swing/ActionMap.h"

#ifndef _JC_javax_swing_plaf_ActionMapUIResource_H_
#define _JC_javax_swing_plaf_ActionMapUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$sub_refs	_jc_javax_swing_plaf_ActionMapUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs	_jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$refs	_jc_javax_swing_plaf_ActionMapUIResource$refs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$nonrefs	_jc_javax_swing_plaf_ActionMapUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_ActionMapUIResource$object	_jc_javax_swing_plaf_ActionMapUIResource$object;

typedef const struct _jc_javax_swing_plaf_ActionMapUIResource$vmethods	_jc_javax_swing_plaf_ActionMapUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_ActionMapUIResource$vtable	_jc_javax_swing_plaf_ActionMapUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_ActionMapUIResource$vtype	_jc_javax_swing_plaf_ActionMapUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ActionMapUIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ActionMapUIResource$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_ActionMapUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ActionMapUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ActionMap$vmethods	javax_swing_ActionMap;
	_jc_javax_swing_plaf_ActionMapUIResource$vmethods	javax_swing_plaf_ActionMapUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_ActionMapUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ActionMapUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ActionMapUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ActionMapUIResource$refs {
    _jc_javax_swing_plaf_ActionMapUIResource$sub_refs	javax_swing_plaf_ActionMapUIResource;
    _jc_javax_swing_ActionMap$sub_refs	javax_swing_ActionMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ActionMapUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ActionMap$sub_nonrefs	javax_swing_ActionMap;
    _jc_javax_swing_plaf_ActionMapUIResource$sub_nonrefs	javax_swing_plaf_ActionMapUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_ActionMapUIResource$object {
	_jc_javax_swing_plaf_ActionMapUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ActionMapUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_ActionMapUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ActionMapUIResource$vtype _jc_javax_swing_plaf_ActionMapUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ActionMapUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ActionMapUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_ActionMapUIResource_H_ */
